.. figure:: images/AiiDA_transparent_logo.png
    :width: 250px
    :align: center

The aiida-orca plugin for `AiiDA`_
=====================================================

``aiida-orca`` is available at http://github.com/aiidateam/aiida-orca


.. toctree::
   :maxdepth: 2

   user_guide/index
   developer_guide/index
   API documentation <apidoc/aiida_orca>

If you use this plugin for your research, please cite the following work:

.. highlights:: Author Name1, Author Name2, *Paper title*, Jornal Name XXX, YYYY (Year).

If you use AiiDA for your research, please cite the following work:

.. highlights:: Giovanni Pizzi, Andrea Cepellotti, Riccardo Sabatini, Nicola Marzari,
  and Boris Kozinsky, *AiiDA: automated interactive infrastructure and database
  for computational science*, Comp. Mat. Sci 111, 218-230 (2016);
  https://doi.org/10.1016/j.commatsci.2015.09.013; http://www.aiida.net.

``aiida-orca`` is released under the MIT license.




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _AiiDA: http://www.aiida.net
